@@ -17,7 +17,8 @@ def create():
 @click.command()
 @click.option("--create", help="Input target object name and create it")
 @click.option("--log", is_flag=True, default=True, help="")
-def zfc(object_name, using_log):
+def zfc(create, log):
+    object_name = create
     if os.path.exists(object_name):
         return
 
@@ -27,3 +28,6 @@ def zfc(object_name, using_log):
     os.mkdir(src_dir)
     with open(config_file, "wb") as fp:
         json.dump(DEFAULT_CONF, fp)
+
+
+zfc()
